==> odoo14_addon_migration_wordpress-14.0.1.0.0-py3-none-any.whl: odoo/addons/migration_wordpress/controllers/main.py <==
# -*- coding: utf-8 -*-

import base64
import werkzeug

import odoo.http as http
import odoo
from odoo.http import request


def binary_content(xmlid=None, model='ir.attachment', id=None, field='datas', unique=False, filename=None, filename_field='datas_fname', download=False, mimetype=None, default_mimetype='application/octet-stream', access_token=None, env=None):
    return request.registry['ir.http'].binary_content(xmlid=xmlid, model=model, id=id, field=field, unique=unique, filename=filename, filename_field=filename_field, download=download, mimetype=mimetype, default_mimetype=default_mimetype, access_token=access_token, env=env)


class ImageResizeHackController(http.Controller):

    def force_contenttype(self, headers, contenttype='image/png'):
        dictheaders = dict(headers)
        dictheaders['Content-Type'] = contenttype
        return list(dictheaders.items())

    @http.route('/web/image2/<int:id>/<int:width>x<int:height>/<string:filename>', type="http", auth="public")
    def content_image(self, xmlid=None, model='ir.attachment', id=None, field='datas', filename_field='datas_fname', unique=None, filename=None, mimetype=None, download=None, width=0, height=0, crop=False, access_token=None):

        status, headers, content = binary_content(xmlid=xmlid, model=model, id=id, field=field, unique=unique, filename=filename,
                                                  filename_field=filename_field, download=download, mimetype=mimetype, default_mimetype='image/png', access_token=access_token)

        if status == 304:
            return werkzeug.wrappers.Response(status=304, headers=headers)
        elif status == 301:
            return werkzeug.utils.redirect(content, code=301)
        elif status != 200 and download:
            return request.not_found()

        height = int(height or 0)
        width = int(width or 0)

        if crop and (width or height):
            content = crop_image(content, type='center',
                                 size=(width, height), ratio=(1, 1))

        elif content and (width or height):
            # resize maximum 500*500

            content = odoo.tools.image_resize_image(base64_source=content, size=(
                width or None, height or None), encoding='base64', filetype='PNG')
            # resize force png as filetype
            headers = self.force_contenttype(headers, contenttype='image/png')

        if content:
            image_base64 = base64.b64decode(content)
        else:
            # could return (contenttype, content) in master
            image_base64 = self.placeholder(image='placeholder.png')
            headers = self.force_contenttype(headers, contenttype='image/png')

        headers.append(('Content-Length', len(image_base64)))
        response = request.make_response(image_base64, headers)
        response.status_code = status
        return response

        status, headers, content = binary_content(xmlid=xmlid, model=model, id=id, field=field, unique=unique, filename=filename,
                                                  filename_field=filename_field, download=download, mimetype=mimetype, default_mimetype='image/png')
        if status == 304:
            return werkzeug.wrappers.Response(status=304, headers=headers)
        elif status == 301:
            return werkzeug.utils.redirect(content, code=301)
        elif status != 200 and download:
            return request.not_found()

        if content and (width or height):
            content = odoo.tools.image_resize_image(base64_source=content, size=(
                width or None, height or None), encoding='base64', filetype='PNG')
            # resize force png as filetype
            headers = self.force_contenttype(headers, contenttype='image/png')

        if content:
            image_base64 = base64.b64decode(content)
        else:
            # could return (contenttype, content) in master
            image_base64 = self.placeholder(image='placeholder.png')
            headers = self.force_contenttype(headers, contenttype='image/png')

        headers.append(('Content-Length', len(image_base64)))
        response = request.make_response(image_base64, headers)
        response.status_code = status
        return response

==> odoo14_addon_migration_wordpress-14.0.2.0.0-py3-none-any.whl: odoo/addons/migration_wordpress/controllers/main.py <==
# -*- coding: utf-8 -*-

import base64
import werkzeug

import odoo.http as http
import odoo
from odoo.http import request


def binary_content(xmlid=None, model='ir.attachment', id=None, field='datas', unique=False, filename=None, download=False, mimetype=None, default_mimetype='application/octet-stream', access_token=None, env=None):
    return request.registry['ir.http'].binary_content(xmlid=xmlid, model=model, id=id, field=field, unique=unique, filename=filename, download=download, mimetype=mimetype, default_mimetype=default_mimetype, access_token=access_token, env=env)


class ImageResizeHackController(http.Controller):

    def force_contenttype(self, headers, contenttype='image/png'):
        dictheaders = dict(headers)
        dictheaders['Content-Type'] = contenttype
        return list(dictheaders.items())

    @http.route('/web/image2/<int:id>/<int:width>x<int:height>/<string:filename>', type="http", auth="public")
    def content_image(self, xmlid=None, model='ir.attachment', id=None, field='datas', unique=None, filename=None, mimetype=None, download=None, width=0, height=0, crop=False, access_token=None):

        status, headers, content = binary_content(xmlid=xmlid, model=model, id=id, field=field, unique=unique, filename=filename,
                                                   download=download, mimetype=mimetype, default_mimetype='image/png', access_token=access_token)

        if status == 304:
            return werkzeug.wrappers.Response(status=304, headers=headers)
        elif status == 301:
            return werkzeug.utils.redirect(content, code=301)
        elif status != 200 and download:
            return request.not_found()

        height = int(height or 0)
        width = int(width or 0)

        if crop and (width or height):
            content = crop_image(content, type='center',
                                 size=(width, height), ratio=(1, 1))

        elif content and (width or height):
            # resize maximum 500*500

            content = odoo.tools.image_resize_image(base64_source=content, size=(
                width or None, height or None), encoding='base64', filetype='PNG')
            # resize force png as filetype
            headers = self.force_contenttype(headers, contenttype='image/png')

        if content:
            image_base64 = base64.b64decode(content)
        else:
            # could return (contenttype, content) in master
            image_base64 = self.placeholder(image='placeholder.png')
            headers = self.force_contenttype(headers, contenttype='image/png')

        headers.append(('Content-Length', len(image_base64)))
        response = request.make_response(image_base64, headers)
        response.status_code = status
        return response

        status, headers, content = binary_content(xmlid=xmlid, model=model, id=id, field=field, unique=unique, filename=filename,
                                                 download=download, mimetype=mimetype, default_mimetype='image/png')
        if status == 304:
            return werkzeug.wrappers.Response(status=304, headers=headers)
        elif status == 301:
            return werkzeug.utils.redirect(content, code=301)
        elif status != 200 and download:
            return request.not_found()

        if content and (width or height):
            content = odoo.tools.image_resize_image(base64_source=content, size=(
                width or None, height or None), encoding='base64', filetype='PNG')
            # resize force png as filetype
            headers = self.force_contenttype(headers, contenttype='image/png')

        if content:
            image_base64 = base64.b64decode(content)
        else:
            # could return (contenttype, content) in master
            image_base64 = self.placeholder(image='placeholder.png')
            headers = self.force_contenttype(headers, contenttype='image/png')

        headers.append(('Content-Length', len(image_base64)))
        response = request.make_response(image_base64, headers)
        response.status_code = status
        return response
